/* src/net/server.c 
 * ============================================================
 * OCSP Responder
 * (c) 2001 by Massimiliano Pala
 * OpenCA released software
 * ============================================================
 */
 
#include "general.h"

#ifdef __FreeBSD__
#include <netinet/in.h>
#endif

#ifdef __Linux__
#include <resolv.h>
#endif

#include <sys/types.h>
#include <sys/socket.h>

#include <openssl/err.h>
#include <openssl/ssl.h>

#include <openssl/conf.h>
#include <openssl/txt_db.h>

#include "support.h"
#include "ocsp_response.h"
#include "http_request.h"

#define  MAX_LINE_DIM		512

/* External General Variables */
extern int debug;
extern int verbose;

HTTP_REQUEST *parse_http_request ( char *buf, long size ) {

	HTTP_REQUEST *req = NULL;
	int i, len, nline;
	char line[MAX_LINE_DIM];
	

	req = (HTTP_REQUEST *) OPENSSL_malloc (sizeof (HTTP_REQUEST));
	if( (req == NULL) || (buf == NULL))
		return (NULL);

	syslog( LOG_INFO,"Request Allocated" );
	syslog( LOG_INFO,"Buf dimension: %ld", size );

	printf( "Request:\n%s\n", buf );

	i = 0; nline = 0;
	while( i < size ) {
		char c;
		syslog( LOG_INFO,"Starting Line (%d)", i );

		len = 0;
		/* Read the line */
		while ( len < MAX_LINE_DIM ) {
			c = buf[len+i];
			// printf("%x",(int) line[len]);
			if( c == '\r' ) {
				i++;
				continue;
			} else if ( c == '\n' ) {
				line[len] = '\x0';
				break;
			} else if ( c == '\x0' ) {
				line[len] = c;
				break;
			} else {
				line[len++] = c;
			}

		}
		if( len < 1 ) break;
		printf("New Line : %s (%d)\n", line, len );
		nline++;
		i += len + 1;

		/* Parse the Line */
		if( nline == 1 ) {
			if ( strncmp( line, "POST", 4 ) == 0 ) {
				req->method = HTTP_POST;
			} else if ( strncmp( line, "GET", 3 ) == 0 ) {
				req->method = HTTP_GET;
			} else {
				/* Unknown */
				req->method = -1;
			}
		}

		printf("Method : %d\n", req->method );
	}

	return (NULL);
}

